0.62.2
    - Clean up changelog

0.62.1

    - Add build name to deployment name/ID
    - Fix user object (and probably other) PATH endpoints
    - Deployment list now is sorted by creation datetime (descending) and includes creation datetime in output (GET /app/{appname}/deployments)
    - Doc fixes

0.62.0

    - Add deployment hook points
    - Add commits object to deployment object

